<?php

namespace Hospital\Pharmacy\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hospital\Pharmacy\Models\Pharmacy;

class PharmacyPolicy
{

    /**
     * Determine if the given user can view the pharmacy.
     *
     * @param UserPolicy $user
     * @param Pharmacy $pharmacy
     *
     * @return bool
     */
    public function view(UserPolicy $user, Pharmacy $pharmacy)
    {
        if ($user->canDo('pharmacy.pharmacy.view') && $user->isAdmin()) {
            return true;
        }

        return $pharmacy->user_id == user_id() && $pharmacy->user_type == user_type();
    }

    /**
     * Determine if the given user can create a pharmacy.
     *
     * @param UserPolicy $user
     * @param Pharmacy $pharmacy
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('pharmacy.pharmacy.create');
    }

    /**
     * Determine if the given user can update the given pharmacy.
     *
     * @param UserPolicy $user
     * @param Pharmacy $pharmacy
     *
     * @return bool
     */
    public function update(UserPolicy $user, Pharmacy $pharmacy)
    {
        if ($user->canDo('pharmacy.pharmacy.edit') && $user->isAdmin()) {
            return true;
        }

        return $pharmacy->user_id == user_id() && $pharmacy->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given pharmacy.
     *
     * @param UserPolicy $user
     * @param Pharmacy $pharmacy
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Pharmacy $pharmacy)
    {
        return $pharmacy->user_id == user_id() && $pharmacy->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given pharmacy.
     *
     * @param UserPolicy $user
     * @param Pharmacy $pharmacy
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Pharmacy $pharmacy)
    {
        if ($user->canDo('pharmacy.pharmacy.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given pharmacy.
     *
     * @param UserPolicy $user
     * @param Pharmacy $pharmacy
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Pharmacy $pharmacy)
    {
        if ($user->canDo('pharmacy.pharmacy.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
