<?php

namespace Hospital\Pharmacy\Providers;

use Illuminate\Support\ServiceProvider;

class PharmacyServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'pharmacy');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'pharmacy');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('hospital.pharmacy', function ($app) {
            return $this->app->make('Hospital\Pharmacy\Pharmacy');
        });

                // Bind Pharmacy to repository
        $this->app->bind(
            'Hospital\Pharmacy\Interfaces\PharmacyRepositoryInterface',
            \Hospital\Pharmacy\Repositories\Eloquent\PharmacyRepository::class
        );

        $this->app->register(\Hospital\Pharmacy\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Hospital\Pharmacy\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['hospital.pharmacy'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('hospital/pharmacy.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/pharmacy')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/pharmacy')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
